/******************************************************************************

  libtpccurveiov.c  (c) 2004-2007 Turku PET Centre

  This file contains function for printing the date and time when this library
  is compiled.

  Version:
  2004-11-07 Vesa Oikonen

  2005-01-20 Calle Laakkonen

  2005-04-26 Jarkko Johansson
  Functions libtpccurveio_print_readme(), libtpccurveio_print_history(),
  libtpccurveio_print_dreadme() and libtpccurveio_print_dhistory()
  are used for getting the Readme and History messages for the libtpccurveio,
  with and without Doxygen style tags. Remember to update the
  functions to get correct Readme and History messages!
  Function libtpccurveio_print_build(), is used for getting the build
  information.

  2005-06-17 1.1.1 Kaisa Sederholm
  New version of dft.c

  2005-10-30 1.2.0 VO
  New version of mathfunc.c and mathfunc.h.
  Small addition in result.c.

  2005-11-30 1.2.1 VO
  Added idwc.c and if.c (i/o for Imanet London TAC formats).

  2005-12-05 1.2.2 KS
  Added a warning to dftWrite() in dft.c

  2006-01-31 1.2.3 VO
  Added a function in mathfunc.c.

  2006-05-15 1.2.4 VO
  Bug correction in dft.c.

  2006-06-03 1.2.5 VO
  Added a function in mathfunc.c.
  Added fields in RES structure in result.h and result.c.

  2006-07-12 1.2.6 VO
  New version of result.c.
  New functions in dft.c, dft.h changed accordingly.

  2006-07-31 1.2.7 VO
  New version of result.c.

  2006-12-01 1.2.8 VO
  Bug correction in dft.c.

  2007-01-15 1.2.9 VO
  Added a function in dft.c and dft.h.
  Added information in HTML files to help importing in Excel.
  Added functions in result.c and result.h.

  2007-01-26 1.2.10 VO
  Bug correction in dft.c.

  2007-02-11 1.3.0 VO
  Added functions for calibration and time unit identification and conversion.
  Added enums for the units.
  Minutes are now represented by DFTUNIT_MIN, which has numerical value 2;
  before it had numerical representation 0, which from now on equals
  DFTUNIT_UNKNOWN.
  
  2007-04-13 1.3.1 VO
  Added function dftSetComments(DFT *dft) to be called before saving DFT file.
  dftRead() calls dftFrametimes() also after reading old format datafile.

  2007-04-20 1.3.2 VO
  Added new function in mathfunc.c.

  2007-04-24 1.3.3 VO
  Bug correction in writing DFT files.

  2007-08-12 1.3.4 VO
  Backup file extension is set with define.
  Change in writing DFT files.
  Bug correction in results file backup writing.

  2007-08-13 1.3.5 VO
  Added petunits.c and .h.
  Functions and enums in dftunit.c and .h replaced by those in petunits.c and .h.

  2007-09-13 1.4.0 VO
  Added fields datanr and fitmethod in RES struct and file format.
  Added function resSelectRegions().
  Return value of localtime() is always checked.


******************************************************************************/

/** Library name. */
#define LIB_NAME "libtpccurveio"

/** Library version. */
#define LIB_VERSION "1.4.0"

/** Copyright. */
#define COPYRIGHT "(c) 2004-2007 by Turku PET Centre"

/*****************************************************************************/
#include <stdio.h>
#include "libtpccurveiov.h"
/*****************************************************************************/


/**
    Print the library readme to specified FILE pointer, use stdout for screen.
*/
void libtpccurveio_print_readme(FILE *fp){
  fputs(
	"\n"
	LIB_NAME" "LIB_VERSION" "COPYRIGHT"\n"
	"\n"
	"Build "__DATE__" "__TIME__"\n"
	"\n"
	"\n"
	"PET time-activity curve IO library\n"
	"-------------------------------------------------------------------------------\n"
	"\n"
	"Library is distributed under the GNU Lesser General Public Licence\n"
	"http://www.turkupetcentre.net/software/lgpl-license.html\n"
	"More information on open source licences: http://www.opensource.org\n"
	"\n"
	"Contents\n"
	"-------------------------------------------------------------------------------\n"
	"\n"
	"include/        - Includes all the header files for the .c files\n"
	"\n"
	"Makefile        - The makefile\n"
	"\n"
	"** .c files **\n"
	"\n"
	"dft.c           -  Working with DFT (TAC) data structure.\n"
	"\n"
	"dftio.c         -  Reading and writing DFT (TAC) files.\n"
	"\n"
	"dftres.c        -  Setting up RES (results) based on DFT (TAC data).\n"
	"\n"
	"petunits.c      -  Calibration and time units definitions for PET data.\n"
	"\n"
	"dftunit.c       -  Calibration and time units processing for DFT files.\n"
	"\n"
	"mathfunc.c      -  Functions for FIT files and mathematical functions.\n"
	"\n"
	"ncifile.c       -  Support previous TAC format (*.roi.kbq/*.roi.nci).\n"
	"\n"
	"result.c        -  Reading and writing result files.\n"
	"\n"
	"cpt.c           -  Functions for reading and writing CPT files.\n"
	"\n"
	"idwc.c          -  Functions for reading and writing IDWC TAC files.\n"
	"\n"
	"if.c            -  Functions for reading and writing IF TAC files.\n"
	"\n"
	"libtpccurveiov.c - Functions for printing the library information.\n"
	"\n"
	"libtpccurveio.c  - Program for printing the library information, \n"
	"                   and for testing the library functions.\n"
	"\n"
	"Using the library\n"
	"-------------------------------------------------------------------------------\n"
	"\n"
	"The program that uses the library should include the .h file it needs.\n"
	"Example:	\\#include <curveio.h>\n"
	"\n"
	"		gcc myprog.c -ltpccurveio -lm\n"
	"\n"
	"\n"
	"\n",
	fp
	);

  fflush(fp);
}

/**
    Print the library History to specified FILE pointer,
    use stdout for screen.
*/
void libtpccurveio_print_history(FILE *fp)
{
  fputs(
	"  2004-11-07 Vesa Oikonen\n"
	"\n"
	"  2005-01-20 Calle Laakkonen\n"
	"\n"
	"  2005-04-26 Jarkko Johansson\n"
	"  Functions libtpccurveio_print_readme(), libtpccurveio_print_history(),\n"
	"  libtpccurveio_print_dreadme() and libtpccurveio_print_dhistory()\n"
	"  are used for getting the Readme and History messages for the libtpccurveio,\n"
	"  with and without Doxygen style tags. Remember to update the\n"
	"  functions to get correct Readme and History messages!\n"
	"\n"
	"  Function libtpccurveio_print_build(), is used for getting the build\n"
	"  information.\n"
	"\n"
	"  Merged with libcpt.\n"
        "\n"
	"  2005-06-17 Kaisa Sederholm\n"
	"  New version of dft.c.\n"
	"\n"
	"  2005-10-30 Vesa Oikonen\n"
	"  New version of mathfunc.c, result.c, and dft.c.\n"
	"\n"
	"  2005-11-30 Vesa Oikonen\n"
	"  Added support to Imanet London TAC files (idwc.c and if.c).\n"
	"\n"
	"  2005-12-05 KS\n"
	"  Added warning if the function dftWrite is writing the file \n"
        "  with a name that allready exists.\n"
	"\n"
	"  2006-01-31 VO\n"
	"  New version of mathfunc.c.\n"
        "\n"
	"  2006-05-15 VO\n"
	"  New version of dft.c.\n"
	"\n"
	"  2006-06-03 VO\n"
	"  Added support for Hill function with background (mathfunc.c).\n"
	"  Added fields in result data structure (result.h and result.c).\n"
	"  Field names in result data structure are case-insensitive.\n"
	"  Field names in fit data structure are case-insensitive.\n"
	"\n"
	"  2006-07-12 VO\n"
	"  New version of result.c.\n"
	"  New functions in dft.c, dft.h changed accordingly.\n"
	"\n"
	"  2006-07-31 VO\n"
	"  New version of result.c, result.h changed accordingly.\n"
	"\n"
	"  2006-12-01 VO\n"
	"  Corrected a bug: existing backup files were not overwritten.\n"
	"\n"
	"  2007-01-15 VO\n"
	"  New functions in dft.c and result.c."
        "  Additions in dft.h and result.h, accordingly.\n"
	"  Corrected a bug: existing result backup files were not overwritten.\n"
	"\n"
	"  2007-01-26 VO\n"
	"  Corrected a bug with XHTML tables of plain DFT data.\n"
	"\n"
	"  2007-02-10 VO\n"
	"  New functions for processing calibration and time units.\n"
	"  Programs that work with time unit MUST be updated to use\n"
        "  DFTTIME_MIN, DFTTIME_SEC or DFTTIME_UNKNOWN.\n"
	"\n"
	"  2007-04-13 VO\n"
	"  New function for adding extra information in comments.\n"
	"\n"
	"  2007-04-20 VO\n"
	"  Corrected bugs in reading and writing fit files.\n"
	"  Added support for Hill function which does not start from 1.0.\n"
	"\n"
	"  2007-04-24 VO\n"
	"  Corrected bug: crashed when writing DFT file was not successful.\n"
	"\n"
	"  2007-08-12 VO\n"
	"  Change in DFT writing defaults.\n"
        "  New functions for setting up results based on DFT data.\n"
        "  Change in function that corrects DFT frame overlapping.\n"
        "  Backup file extension can be changed by defining BACKUP_EXTENSION\n"
        "  before including any TPC libraries; remember to include the '.'.\n"
	"\n",
	fp
	);
  fputs(
	"  2007-09-13 VO\n"
	"  Added fields datanr and fitmethod in RES struct.\n"
	"  Added function resSelectRegions().\n"
	"\n",
	fp
	);
  fflush(fp);
}

/**
    Print the library Readme to specified FILE pointer with Doxygen tags,
    use stdout for screen.
*/
void libtpccurveio_print_dreadme(FILE *fp)
{
  fprintf(fp,"/**\n\\mainpage %s %s %s\n\\section readme Readme\n<pre>\n",
    LIB_NAME, LIB_VERSION, COPYRIGHT);
  libtpccurveio_print_readme(fp);
  fprintf(fp,"\n</pre> \n */\n");
}

/**
    Print the library History to specified FILE pointer with Doxygen tags,
    use stdout for screen.
*/
void libtpccurveio_print_dhistory(FILE *fp)
{
  fprintf(fp,"/**\n\\page History\n\\section history History\n<pre>\n");
  libtpccurveio_print_history(fp);
  fprintf(fp,"\n</pre> \n */\n");
}

/**
    Print the build info to specified FILE pointer, use stdout for screen.
*/
void libtpccurveio_print_build(FILE *fp)
{
  fprintf(fp,"\n %s %s %s\n", LIB_NAME, LIB_VERSION, COPYRIGHT);
  fprintf(fp,"\n Build %s %s\n", __DATE__, __TIME__);
}



/** Print the compilation date and time to specified FILE pointer  */
void libtpccurveio_printdate(FILE *fp)
{
  libtpccurveio_print_build(fp);
}

/*****************************************************************************/

